@@ -1,14 +1,12 @@
 package Text::Todo::Simple::Command;
-BEGIN {
-  $Text::Todo::Simple::Command::VERSION = '0.16';
+{
+  $Text::Todo::Simple::Command::VERSION = '0.17';
 }
 
 use App::Cmd::Setup -command;
 
-use Carp;
-
-use warnings;
 use strict;
+use warnings;
 
 =head1 NAME
 
@@ -16,7 +14,7 @@ Text::Todo::Simple::Command - Base class for Text::Todo::Simple commands
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 METHODS
 
@@ -94,4 +92,4 @@ See http://dev.perl.org/licenses/ for more information.
 
 =cut
 
-1; # End of Text::Todo::Simple::Command
\ No newline at end of file
+1; # End of Text::Todo::Simple::Command
